
Loads
=====


.. automodule:: opendssdirect.Loads
            :members:
            :undoc-members:
            :show-inheritance:

.. function:: opendssdirect.Loads.AllNames

    The names of all the loads present in the active circuit. The result is delivered as variant, however, the content of this variant is an array of strings.

.. function:: opendssdirect.Loads.AllocationFactor

    The AllocationFactor property of the active load. The parameter argument can be filled with a 0.Set the AllocationFactor property of the active load. The parameter argument must contain the new value in AllocationFactor for the desired active load. The return value will be equal to 0.

.. function:: opendssdirect.Loads.CFactor

    The CFactor property of the active load. The parameter argument can be filled with a 0.Set the CFactor property of the active load. The parameter argument must contain the new value in CFactor for the desired active load. The return value will be equal to 0.

.. function:: opendssdirect.Loads.CVRCurve

    The CVRCUrve property of the active load. The parameter argument can be filled with an empty string.Set the CVRCurve property for the active load. The parameter argument must contain the Name of the new CVRCurve to be linked to the active load. The return value will be equal to empty.

.. function:: opendssdirect.Loads.CVRvars

    The CVRvars property of the active load. The parameter argument can be filled with a 0.Set the CVRvars property of the active load. The parameter argument must contain the new value in CVRvars for the desired active load. The return value will be equal to 0.

.. function:: opendssdirect.Loads.CVRwatts

    The CVRWatts property of the active load. The parameter argument can be filled with a 0.Set the CVRWatts property of the active load. The parameter argument must contain the new value in CVRWatts for the desired active load. The return value will be equal to 0.

.. function:: opendssdirect.Loads.Class

    The code number used to separate Loads by class or group. The parameter argument can be filled with a 0.The code number used to separate loads by class or group. The parameter argument can be filled with a 0.

.. function:: opendssdirect.Loads.Count

    Returns the number of load elements within the active circuit. The parameter argument can be filled with a 0.

.. function:: opendssdirect.Loads.Daily

    The daily property of the active load. The parameter argument can be filled with an empty string.Set the daily property for the active load. The parameter argument must contain the Name of the new daily to be linked to the active load. The return value will be equal to empty.

.. function:: opendssdirect.Loads.Duty

    The duty property of the active load. The parameter argument can be filled with an empty string.Set the duty property for the active load. The parameter argument must contain the Name of the new duty to be linked to the active load. The return value will be equal to empty.

.. function:: opendssdirect.Loads.First

    Allows to set the active load into the first load registered in the active circuit. As a result, this property will return the number 1. The parameter argument can be filled with a 0.

.. function:: opendssdirect.Loads.Growth

    The Growth property of the active load. The parameter argument can be filled with an empty string.Set the Growth property for the active load. The parameter argument must contain the Name of the new Growth to be linked to the active load. The return value will be equal to empty.

.. function:: opendssdirect.Loads.Idx

    The index of the active load. The parameter argument can be filled with a 0.Set the index of the active load. The parameter argument must contain the index of the desired active load. The return value will be equal to 0.

.. function:: opendssdirect.Loads.IsDelta

    If true, loads are line to line.Set whether loads are delta (line to line).

.. function:: opendssdirect.Loads.Model

    The model of the active load. The parameter argument can be filled with a 0.Set the model of the active load using the parameter argument. return a 0.

.. function:: opendssdirect.Loads.Name

    The Name property of the active load. The parameter argument can be filled with an empty string.Set the active load by specifying the Name load. The parameter argument must contain the Name of the load to activate. The return value will be equal to empty.

.. function:: opendssdirect.Loads.Next

    Set the active load into the next load registered in the active circuit. As a result, this property will set the index of the active load. The parameter argument can be filled with a 0.

.. function:: opendssdirect.Loads.NumCust

    The number of customer of the active load. The parameter argument can be filled with a 0.Set the number of customers of the active load using the parameter argument. return a 0.

.. function:: opendssdirect.Loads.PF

    The pf property of the active load. The parameter argument can be filled with a 0.Set the pf property of the active load. The parameter argument must contain the new value in pf for the desired active load. The return value will be equal to 0.

.. function:: opendssdirect.Loads.PctMean

    The PctMean property of the active load. The parameter argument can be filled with a 0.Set the PctMean property of the active load. The parameter argument must contain the new value in PctMean for the desired active load. The return value will be equal to 0.

.. function:: opendssdirect.Loads.PctStdDev

    The PctStdDev property of the active load. The parameter argument can be filled with a 0.Set the PctStdDev property of the active load. The parameter argument must contain the new value in PctStdDev for the desired active load. The return value will be equal to 0.

.. function:: opendssdirect.Loads.RelWeighting

    The RelWeight (relative weighting factor) property of the active load. The parameter argument can be filled with a 0.Set the RelWeight (relative weighting factor) property of the active load. The parameter argument must contain the new value in RelWeight for the desired active load. The return value will be equal to 0.

.. function:: opendssdirect.Loads.Rneut

    The RNeut (neutral resistance for wye connected loads) property of the active load. The parameter argument can be filled with a 0.Set the RNeut (neutral resistance for wye connected loads) property of the active load. The parameter argument must contain the new value in RNeut for the desired active load. The return value will be equal to 0.

.. function:: opendssdirect.Loads.Spectrum

    The Spectrum property of the active load. The parameter argument can be filled with an empty string.Set the Spectrum property for the active load. The parameter argument must contain the Name of the new Spectrum to be linked to the active load. The return value will be equal to empty.

.. function:: opendssdirect.Loads.Status

    

.. function:: opendssdirect.Loads.Vmaxpu

    The VMaxpu property of the active load. The parameter argument can be filled with a 0.Set the VMaxpu property of the active load. The parameter argument must contain the new value in VMaxpu for the desired active load. The return value will be equal to 0.

.. function:: opendssdirect.Loads.VminEmerg

    The VMinemerg property of the active load. The parameter argument can be filled with a 0.Set the VMinemerg property of the active load. The parameter argument must contain the new value in VMinemerg for the desired active load. The return value will be equal to 0.

.. function:: opendssdirect.Loads.VminNorm

    The VMinnorm property of the active load. The parameter argument can be filled with a 0.Set the VMinnorm property of the active load. The parameter argument must contain the new value in VMinnorm for the desired active load. The return value will be equal to 0.

.. function:: opendssdirect.Loads.Vminpu

    The VMinpu property of the active load. The parameter argument can be filled with a 0.Set the VMinpu property of the active load. The parameter argument must contain the new value in VMinpu for the desired active load. The return value will be equal to 0.

.. function:: opendssdirect.Loads.XfkVA

    The xfKVA (Rated service transformer KVA for load allocation, using Allocationfactor. Affects kW, kvar and pf.) property of the active load. The parameter argument can be filled with a 0.Set the xfKVA (Rated service transformer KVA for load allocation, using Allocationfactor. Affects kW, kvar and pf.) property of the active load. The parameter argument must contain the new value in xfKVA for the desired active load. The return value will be equal to 0.

.. function:: opendssdirect.Loads.Xneut

    The Xneut property of the active load. The parameter argument can be filled with a 0.Set the Xneut property of the active load. The parameter argument must contain the new value in Xneut for the desired active load. The return value will be equal to 0.

.. function:: opendssdirect.Loads.Yearly

    The Yearly property of the active load. The parameter argument can be filled with an empty string.Set the Yearly property for the active load. The parameter argument must contain the Name of the new Yearly to be linked to the active load. The return value will be equal to empty.

.. function:: opendssdirect.Loads.ZipV

    The array of 7 elements (doubles) for ZIP property of the active Load object.

.. function:: opendssdirect.Loads.kV

    The kV property of the active load. The parameter argument can be filled with a 0.Set the kV property of the active load. The parameter argument must contain the new value in kV for the desired active load. The return value will be equal to 0.

.. function:: opendssdirect.Loads.kVABase

    The kva property of the active load. The parameter argument can be filled with a 0.Set the kva property of the active load. The parameter argument must contain the new value in kva for the desired active load. The return value will be equal to 0.

.. function:: opendssdirect.Loads.kW

    The kW property of the active load. The parameter argument can be filled with a 0.Set the kW property of the active load. The parameter argument must contain the new value in kW for the desired active load. The return value will be equal to 0.

.. function:: opendssdirect.Loads.kWh

    The kWh property of the active load. The parameter argument can be filled with a 0.Set the kWh property of the active load. The parameter argument must contain the new value in kWh for the desired active load. The return value will be equal to 0.

.. function:: opendssdirect.Loads.kWhDays

    The kWhdays property of the active load. The parameter argument can be filled with a 0.Set the kWhdays property of the active load. The parameter argument must contain the new value in kWhdays for the desired active load. The return value will be equal to 0.

.. function:: opendssdirect.Loads.kvar

    The kvar property of the active load. The parameter argument can be filled with a 0.Set the kvar property of the active load. The parameter argument must contain the new value in kvar for the desired active load. The return value will be equal to 0.

.. function:: opendssdirect.Loads.puSeriesRL

    The PctSeriesRL (Percent of Load that is modeled as series R-L for harmonic studies) property of the active load. The parameter argument can be filled with a 0.Set the PctSeriesRL (Percent of Load that is modeled as series R-L for harmonic studies) property of the active load. The parameter argument must contain the new value in PctSeriesRL for the desired active load. The return value will be equal to 0.

